==> mgb-0.6.7.tar.gz: includes/captcha.inc.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ======================= //
	// captcha.inc.php - 1.2.1 //
	// ======================= //
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	require ("config.inc.php");
	require ("functions.inc.php");
	require ("load_settings.inc.php");

	// randomly choose a background for the captcha
	$captcha_randombg = rand(1, 34);
	$captcha_img = imagecreatefrompng ("../images/".$settings['iconset_path']."/captchas/captchabg".$captcha_randombg.".png");

	if ($settings['captcha_method'] == 0)
		{
		// get code from database
		$sql = "SELECT `code` FROM ".$db['prefix']."captcha";
		$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(captcha.inc.php) Error, line 39: ".mysql_error());
		mysql_select_db($db['dbname'], $link) or die ("(captcha.inc.php) Error, line 40: ".mysql_error());
		$result = mysql_query($sql, $link) or die ("(captcha.inc.php) Error, line 41: ".mysql_error());

		$captcha = @mysql_fetch_array($result);
		$captcha_text = $captcha['code'];

		$textwidth = (120 - 100);
		$textheight = (40 - 15);
		$textcolor = imagecolorallocate($captcha_img, 80, 80, 80);
		$angle = rand(-5, 2);
		imagettftext($captcha_img, 22, $angle, $textwidth, $textheight, $textcolor, "../fonts/akoom.ttf", $captcha_text);
		}
	else
		{
		// get code from database
		$sql = "SELECT `math` FROM ".$db['prefix']."captcha_math";
		$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(captcha.inc.php) Error, line 56: ".mysql_error());
		mysql_select_db($db['dbname'], $link) or die ("(captcha.inc.php) Error, line 57: ".mysql_error());
		$result = mysql_query($sql, $link) or die ("(captcha.inc.php) Error, line 58: ".mysql_error());

		$captcha = @mysql_fetch_array($result);
		$captcha_text = $captcha['math'];

		$textwidth = (120 - 100);
		$textheight = (40 - 15);
		$textcolor = imagecolorallocate($captcha_img, 80, 80, 80);
		$angle = rand(-5, 5);
		imagettftext($captcha_img, 18, $angle, $textwidth, $textheight, $textcolor, "../fonts/acidic.ttf", $captcha_text);
		}

	// The font "akoom.ttf" used in here is copyrighted by http://veredgf.fredfarm.com/.
	// It is NOT released under GNU/GPL. It's Freeware. This means you can use and
	// share it for free but you may NOT sell it!

	imagepng($captcha_img);
?>

==> mgb-0.6.8.tar.gz: includes/captcha.inc.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ======================= //
	// captcha.inc.php - 1.2.1 //
	// ======================= //
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	require ("config.inc.php");
	require ("functions.inc.php");
	require ("load_settings.inc.php");

	// randomly choose a background for the captcha
	/*$captcha_dir = opendir('../images/captchas/');
	$filecounter = 0;
	while($res = readdir($captcha_dir))
		{
		$filecounter++;
		}
	closedir($captcha_dir);
	echo "<span color='#ffffff'>".$filecounter."</span>";*/
	$captcha_randombg = rand(1, 34);
	$captcha_img = imagecreatefrompng ("../images/captchas/captchabg".$captcha_randombg.".png");

	if ($settings['captcha_method'] == 0)
		{
		// get code from database
		$sql = "SELECT `code` FROM ".$db['prefix']."captcha";
		$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(captcha.inc.php) Error, line 39: ".mysql_error());
		mysql_select_db($db['dbname'], $link) or die ("(captcha.inc.php) Error, line 40: ".mysql_error());
		$result = mysql_query($sql, $link) or die ("(captcha.inc.php) Error, line 41: ".mysql_error());

		$captcha = @mysql_fetch_array($result);
		$captcha_text = $captcha['code'];

		$textwidth = (120 - 100);
		$textheight = (40 - 15);
		$textcolor = imagecolorallocate($captcha_img, 80, 80, 80);
		$angle = rand(-5, 2);
		imagettftext($captcha_img, 22, $angle, $textwidth, $textheight, $textcolor, "../fonts/akoom.ttf", $captcha_text);
		}
	else
		{
		// get code from database
		$sql = "SELECT `math` FROM ".$db['prefix']."captcha_math";
		$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(captcha.inc.php) Error, line 56: ".mysql_error());
		mysql_select_db($db['dbname'], $link) or die ("(captcha.inc.php) Error, line 57: ".mysql_error());
		$result = mysql_query($sql, $link) or die ("(captcha.inc.php) Error, line 58: ".mysql_error());

		$captcha = @mysql_fetch_array($result);
		$captcha_text = $captcha['math'];

		$textwidth = (120 - 100);
		$textheight = (40 - 15);
		$textcolor = imagecolorallocate($captcha_img, 80, 80, 80);
		$angle = rand(-5, 5);
		imagettftext($captcha_img, 18, $angle, $textwidth, $textheight, $textcolor, "../fonts/acidic.ttf", $captcha_text);
		}

	// The font "akoom.ttf" used in here is copyrighted by http://veredgf.fredfarm.com/.
	// It is NOT released under GNU/GPL. It's Freeware. This means you can use and
	// share it for free but you may NOT sell it!

	imagepng($captcha_img);
?>
